@@ -2,7 +2,7 @@ from pydantic import BaseSettings, Field, PyObject
 
 
 class DatabaseSettings(BaseSettings):
-    url: str = Field("postgres://localhost:5432", env="DATABASE_URL")
+    url: str = Field("postgresql+asyncpg://localhost:5432", env="DATABASE_URL")
     pool_size: int = Field(10, env="DATABASE_POOL_SIZE")
     echo: bool = Field(False, env="DATABASE_ECHO")
     echo_pool: bool = Field(True, env="DATABASE_ECHO_POOL")
